Class: Aws::LakeFormation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LakeFormation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lakeformation/client.rb,
sig/client.rbs
Overview
An API client for LakeFormation. To construct a client, you need to configure a :region and :credentials.
client = Aws::LakeFormation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddLFTagsToResourceResponseSuccess, _AssumeDecoratedRoleWithSAMLResponseSuccess, _BatchGrantPermissionsResponseSuccess, _BatchRevokePermissionsResponseSuccess, _CancelTransactionResponseSuccess, _CommitTransactionResponseSuccess, _CreateDataCellsFilterResponseSuccess, _CreateLFTagExpressionResponseSuccess, _CreateLFTagResponseSuccess, _CreateLakeFormationIdentityCenterConfigurationResponseSuccess, _CreateLakeFormationOptInResponseSuccess, _DeleteDataCellsFilterResponseSuccess, _DeleteLFTagExpressionResponseSuccess, _DeleteLFTagResponseSuccess, _DeleteLakeFormationIdentityCenterConfigurationResponseSuccess, _DeleteLakeFormationOptInResponseSuccess, _DeleteObjectsOnCancelResponseSuccess, _DeregisterResourceResponseSuccess, _DescribeLakeFormationIdentityCenterConfigurationResponseSuccess, _DescribeResourceResponseSuccess, _DescribeTransactionResponseSuccess, _ExtendTransactionResponseSuccess, _GetDataCellsFilterResponseSuccess, _GetDataLakePrincipalResponseSuccess, _GetDataLakeSettingsResponseSuccess, _GetEffectivePermissionsForPathResponseSuccess, _GetLFTagExpressionResponseSuccess, _GetLFTagResponseSuccess, _GetQueryStateResponseSuccess, _GetQueryStatisticsResponseSuccess, _GetResourceLFTagsResponseSuccess, _GetTableObjectsResponseSuccess, _GetTemporaryDataLocationCredentialsResponseSuccess, _GetTemporaryGluePartitionCredentialsResponseSuccess, _GetTemporaryGlueTableCredentialsResponseSuccess, _GetWorkUnitResultsResponseSuccess, _GetWorkUnitsResponseSuccess, _GrantPermissionsResponseSuccess, _ListDataCellsFilterResponseSuccess, _ListLFTagExpressionsResponseSuccess, _ListLFTagsResponseSuccess, _ListLakeFormationOptInsResponseSuccess, _ListPermissionsResponseSuccess, _ListResourcesResponseSuccess, _ListTableStorageOptimizersResponseSuccess, _ListTransactionsResponseSuccess, _PutDataLakeSettingsResponseSuccess, _RegisterResourceResponseSuccess, _RemoveLFTagsFromResourceResponseSuccess, _RevokePermissionsResponseSuccess, _SearchDatabasesByLFTagsResponseSuccess, _SearchTablesByLFTagsResponseSuccess, _StartQueryPlanningResponseSuccess, _StartTransactionResponseSuccess, _UpdateDataCellsFilterResponseSuccess, _UpdateLFTagExpressionResponseSuccess, _UpdateLFTagResponseSuccess, _UpdateLakeFormationIdentityCenterConfigurationResponseSuccess, _UpdateResourceResponseSuccess, _UpdateTableObjectsResponseSuccess, _UpdateTableStorageOptimizerResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_lf_tags_to_resource(params = {}) ⇒ Types::AddLFTagsToResourceResponse
Attaches one or more LF-tags to an existing resource.
-
#assume_decorated_role_with_saml(params = {}) ⇒ Types::AssumeDecoratedRoleWithSAMLResponse
Allows a caller to assume an IAM role decorated as the SAML user specified in the SAML assertion included in the request.
-
#batch_grant_permissions(params = {}) ⇒ Types::BatchGrantPermissionsResponse
Batch operation to grant permissions to the principal.
-
#batch_revoke_permissions(params = {}) ⇒ Types::BatchRevokePermissionsResponse
Batch operation to revoke permissions from the principal.
-
#cancel_transaction(params = {}) ⇒ Struct
Attempts to cancel the specified transaction.
-
#commit_transaction(params = {}) ⇒ Types::CommitTransactionResponse
Attempts to commit the specified transaction.
-
#create_data_cells_filter(params = {}) ⇒ Struct
Creates a data cell filter to allow one to grant access to certain columns on certain rows.
-
#create_lake_formation_identity_center_configuration(params = {}) ⇒ Types::CreateLakeFormationIdentityCenterConfigurationResponse
Creates an IAM Identity Center connection with Lake Formation to allow IAM Identity Center users and groups to access Data Catalog resources.
-
#create_lake_formation_opt_in(params = {}) ⇒ Struct
Enforce Lake Formation permissions for the given databases, tables, and principals.
-
#create_lf_tag(params = {}) ⇒ Struct
Creates an LF-tag with the specified name and values.
-
#create_lf_tag_expression(params = {}) ⇒ Struct
Creates a new LF-Tag expression with the provided name, description, catalog ID, and expression body.
-
#delete_data_cells_filter(params = {}) ⇒ Struct
Deletes a data cell filter.
-
#delete_lake_formation_identity_center_configuration(params = {}) ⇒ Struct
Deletes an IAM Identity Center connection with Lake Formation.
-
#delete_lake_formation_opt_in(params = {}) ⇒ Struct
Remove the Lake Formation permissions enforcement of the given databases, tables, and principals.
-
#delete_lf_tag(params = {}) ⇒ Struct
Deletes an LF-tag by its key name.
-
#delete_lf_tag_expression(params = {}) ⇒ Struct
Deletes the LF-Tag expression.
-
#delete_objects_on_cancel(params = {}) ⇒ Struct
For a specific governed table, provides a list of Amazon S3 objects that will be written during the current transaction and that can be automatically deleted if the transaction is canceled.
-
#deregister_resource(params = {}) ⇒ Struct
Deregisters the resource as managed by the Data Catalog.
-
#describe_lake_formation_identity_center_configuration(params = {}) ⇒ Types::DescribeLakeFormationIdentityCenterConfigurationResponse
Retrieves the instance ARN and application ARN for the connection.
-
#describe_resource(params = {}) ⇒ Types::DescribeResourceResponse
Retrieves the current data access role for the given resource registered in Lake Formation.
-
#describe_transaction(params = {}) ⇒ Types::DescribeTransactionResponse
Returns the details of a single transaction.
-
#extend_transaction(params = {}) ⇒ Struct
Indicates to the service that the specified transaction is still active and should not be treated as idle and aborted.
-
#get_data_cells_filter(params = {}) ⇒ Types::GetDataCellsFilterResponse
Returns a data cells filter.
-
#get_data_lake_principal(params = {}) ⇒ Types::GetDataLakePrincipalResponse
Returns the identity of the invoking principal.
-
#get_data_lake_settings(params = {}) ⇒ Types::GetDataLakeSettingsResponse
Retrieves the list of the data lake administrators of a Lake Formation-managed data lake.
-
#get_effective_permissions_for_path(params = {}) ⇒ Types::GetEffectivePermissionsForPathResponse
Returns the Lake Formation permissions for a specified table or database resource located at a path in Amazon S3.
-
#get_lf_tag(params = {}) ⇒ Types::GetLFTagResponse
Returns an LF-tag definition.
-
#get_lf_tag_expression(params = {}) ⇒ Types::GetLFTagExpressionResponse
Returns the details about the LF-Tag expression.
-
#get_query_state(params = {}) ⇒ Types::GetQueryStateResponse
Returns the state of a query previously submitted.
-
#get_query_statistics(params = {}) ⇒ Types::GetQueryStatisticsResponse
Retrieves statistics on the planning and execution of a query.
-
#get_resource_lf_tags(params = {}) ⇒ Types::GetResourceLFTagsResponse
Returns the LF-tags applied to a resource.
-
#get_table_objects(params = {}) ⇒ Types::GetTableObjectsResponse
Returns the set of Amazon S3 objects that make up the specified governed table.
-
#get_temporary_data_location_credentials(params = {}) ⇒ Types::GetTemporaryDataLocationCredentialsResponse
Allows a user or application in a secure environment to access data in a specific Amazon S3 location registered with Lake Formation by providing temporary scoped credentials that are limited to the requested data location and the caller's authorized access level.
-
#get_temporary_glue_partition_credentials(params = {}) ⇒ Types::GetTemporaryGluePartitionCredentialsResponse
This API is identical to
GetTemporaryTableCredentialsexcept that this is used when the target Data Catalog resource is of type Partition. -
#get_temporary_glue_table_credentials(params = {}) ⇒ Types::GetTemporaryGlueTableCredentialsResponse
Allows a caller in a secure environment to assume a role with permission to access Amazon S3.
-
#get_work_unit_results(params = {}) ⇒ Types::GetWorkUnitResultsResponse
Returns the work units resulting from the query.
-
#get_work_units(params = {}) ⇒ Types::GetWorkUnitsResponse
Retrieves the work units generated by the
StartQueryPlanningoperation. -
#grant_permissions(params = {}) ⇒ Struct
Grants permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3.
-
#list_data_cells_filter(params = {}) ⇒ Types::ListDataCellsFilterResponse
Lists all the data cell filters on a table.
-
#list_lake_formation_opt_ins(params = {}) ⇒ Types::ListLakeFormationOptInsResponse
Retrieve the current list of resources and principals that are opt in to enforce Lake Formation permissions.
-
#list_lf_tag_expressions(params = {}) ⇒ Types::ListLFTagExpressionsResponse
Returns the LF-Tag expressions in caller’s account filtered based on caller's permissions.
-
#list_lf_tags(params = {}) ⇒ Types::ListLFTagsResponse
Lists LF-tags that the requester has permission to view.
-
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Returns a list of the principal permissions on the resource, filtered by the permissions of the caller.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources registered to be managed by the Data Catalog.
-
#list_table_storage_optimizers(params = {}) ⇒ Types::ListTableStorageOptimizersResponse
Returns the configuration of all storage optimizers associated with a specified table.
-
#list_transactions(params = {}) ⇒ Types::ListTransactionsResponse
Returns metadata about transactions and their status.
-
#put_data_lake_settings(params = {}) ⇒ Struct
Sets the list of data lake administrators who have admin privileges on all resources managed by Lake Formation.
-
#register_resource(params = {}) ⇒ Struct
Registers the resource as managed by the Data Catalog.
-
#remove_lf_tags_from_resource(params = {}) ⇒ Types::RemoveLFTagsFromResourceResponse
Removes an LF-tag from the resource.
-
#revoke_permissions(params = {}) ⇒ Struct
Revokes permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3.
-
#search_databases_by_lf_tags(params = {}) ⇒ Types::SearchDatabasesByLFTagsResponse
This operation allows a search on
DATABASEresources byTagCondition. -
#search_tables_by_lf_tags(params = {}) ⇒ Types::SearchTablesByLFTagsResponse
This operation allows a search on
TABLEresources byLFTags. -
#start_query_planning(params = {}) ⇒ Types::StartQueryPlanningResponse
Submits a request to process a query statement.
-
#start_transaction(params = {}) ⇒ Types::StartTransactionResponse
Starts a new transaction and returns its transaction ID.
-
#update_data_cells_filter(params = {}) ⇒ Struct
Updates a data cell filter.
-
#update_lake_formation_identity_center_configuration(params = {}) ⇒ Struct
Updates the IAM Identity Center connection parameters.
-
#update_lf_tag(params = {}) ⇒ Struct
Updates the list of possible values for the specified LF-tag key.
-
#update_lf_tag_expression(params = {}) ⇒ Struct
Updates the name of the LF-Tag expression to the new description and expression body provided.
-
#update_resource(params = {}) ⇒ Struct
Updates the data access role used for vending access to the given (registered) resource in Lake Formation.
-
#update_table_objects(params = {}) ⇒ Struct
Updates the manifest of Amazon S3 objects that make up the specified governed table.
-
#update_table_storage_optimizer(params = {}) ⇒ Types::UpdateTableStorageOptimizerResponse
Updates the configuration of the storage optimizers for a table.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-lakeformation/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4384 4385 4386 |
# File 'lib/aws-sdk-lakeformation/client.rb', line 4384 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4387 4388 4389 |
# File 'lib/aws-sdk-lakeformation/client.rb', line 4387 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#add_lf_tags_to_resource(params = {}) ⇒ Types::AddLFTagsToResourceResponse
Attaches one or more LF-tags to an existing resource.
86 |
# File 'sig/client.rbs', line 86 def add_lf_tags_to_resource: ( |
#assume_decorated_role_with_saml(params = {}) ⇒ Types::AssumeDecoratedRoleWithSAMLResponse
Allows a caller to assume an IAM role decorated as the SAML user specified in the SAML assertion included in the request. This decoration allows Lake Formation to enforce access policies against the SAML users and groups. This API operation requires SAML federation setup in the caller’s account as it can only be called with valid SAML assertions. Lake Formation does not scope down the permission of the assumed role. All permissions attached to the role via the SAML federation setup will be included in the role session.
This decorated role is expected to access data in Amazon S3 by getting
temporary access from Lake Formation which is authorized via the
virtual API GetDataAccess. Therefore, all SAML roles that can be
assumed via AssumeDecoratedRoleWithSAML must at a minimum include
lakeformation:GetDataAccess in their role policies. A typical IAM
policy attached to such a role would include the following actions:
-
glue:Database
-
glue:Table
-
glue:Partition
-
glue:UserDefinedFunction
-
lakeformation:GetDataAccess
107 |
# File 'sig/client.rbs', line 107 def assume_decorated_role_with_saml: ( |
#batch_grant_permissions(params = {}) ⇒ Types::BatchGrantPermissionsResponse
Batch operation to grant permissions to the principal.
120 |
# File 'sig/client.rbs', line 120 def batch_grant_permissions: ( |
#batch_revoke_permissions(params = {}) ⇒ Types::BatchRevokePermissionsResponse
Batch operation to revoke permissions from the principal.
133 |
# File 'sig/client.rbs', line 133 def batch_revoke_permissions: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 |
# File 'lib/aws-sdk-lakeformation/client.rb', line 4357 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LakeFormation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-lakeformation' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_transaction(params = {}) ⇒ Struct
Attempts to cancel the specified transaction. Returns an exception if the transaction was previously committed.
145 |
# File 'sig/client.rbs', line 145 def cancel_transaction: ( |
#commit_transaction(params = {}) ⇒ Types::CommitTransactionResponse
Attempts to commit the specified transaction. Returns an exception if the transaction was previously aborted. This API action is idempotent if called multiple times for the same transaction.
155 |
# File 'sig/client.rbs', line 155 def commit_transaction: ( |
#create_data_cells_filter(params = {}) ⇒ Struct
Creates a data cell filter to allow one to grant access to certain columns on certain rows.
164 |
# File 'sig/client.rbs', line 164 def create_data_cells_filter: ( |
#create_lake_formation_identity_center_configuration(params = {}) ⇒ Types::CreateLakeFormationIdentityCenterConfigurationResponse
Creates an IAM Identity Center connection with Lake Formation to allow IAM Identity Center users and groups to access Data Catalog resources.
202 |
# File 'sig/client.rbs', line 202 def create_lake_formation_identity_center_configuration: ( |
#create_lake_formation_opt_in(params = {}) ⇒ Struct
Enforce Lake Formation permissions for the given databases, tables, and principals.
232 |
# File 'sig/client.rbs', line 232 def create_lake_formation_opt_in: ( |
#create_lf_tag(params = {}) ⇒ Struct
Creates an LF-tag with the specified name and values.
173 |
# File 'sig/client.rbs', line 173 def create_lf_tag: ( |
#create_lf_tag_expression(params = {}) ⇒ Struct
Creates a new LF-Tag expression with the provided name, description, catalog ID, and expression body. This call fails if a LF-Tag expression with the same name already exists in the caller’s account or if the underlying LF-Tags don't exist. To call this API operation, caller needs the following Lake Formation permissions:
CREATE_LF_TAG_EXPRESSION on the root catalog resource.
GRANT_WITH_LF_TAG_EXPRESSION on all underlying LF-Tag key:value
pairs included in the expression.
184 |
# File 'sig/client.rbs', line 184 def create_lf_tag_expression: ( |
#delete_data_cells_filter(params = {}) ⇒ Struct
Deletes a data cell filter.
247 |
# File 'sig/client.rbs', line 247 def delete_data_cells_filter: ( |
#delete_lake_formation_identity_center_configuration(params = {}) ⇒ Struct
Deletes an IAM Identity Center connection with Lake Formation.
279 |
# File 'sig/client.rbs', line 279 def delete_lake_formation_identity_center_configuration: ( |
#delete_lake_formation_opt_in(params = {}) ⇒ Struct
Remove the Lake Formation permissions enforcement of the given databases, tables, and principals.
288 |
# File 'sig/client.rbs', line 288 def delete_lake_formation_opt_in: ( |
#delete_lf_tag(params = {}) ⇒ Struct
Deletes an LF-tag by its key name. The operation fails if the specified tag key doesn't exist. When you delete an LF-Tag:
-
The associated LF-Tag policy becomes invalid.
-
Resources that had this tag assigned will no longer have the tag policy applied to them.
259 |
# File 'sig/client.rbs', line 259 def delete_lf_tag: ( |
#delete_lf_tag_expression(params = {}) ⇒ Struct
Deletes the LF-Tag expression. The caller must be a data lake admin or
have DROP permissions on the LF-Tag expression. Deleting a LF-Tag
expression will also delete all LFTagPolicy permissions referencing
the LF-Tag expression.
269 |
# File 'sig/client.rbs', line 269 def delete_lf_tag_expression: ( |
#delete_objects_on_cancel(params = {}) ⇒ Struct
For a specific governed table, provides a list of Amazon S3 objects that will be written during the current transaction and that can be automatically deleted if the transaction is canceled. Without this call, no Amazon S3 objects are automatically deleted when a transaction cancels.
The Glue ETL library function write_dynamic_frame.from_catalog()
includes an option to automatically call DeleteObjectsOnCancel
before writes. For more information, see Rolling Back Amazon S3
Writes.
303 |
# File 'sig/client.rbs', line 303 def delete_objects_on_cancel: ( |
#deregister_resource(params = {}) ⇒ Struct
Deregisters the resource as managed by the Data Catalog.
When you deregister a path, Lake Formation removes the path from the inline policy attached to your service-linked role.
321 |
# File 'sig/client.rbs', line 321 def deregister_resource: ( |
#describe_lake_formation_identity_center_configuration(params = {}) ⇒ Types::DescribeLakeFormationIdentityCenterConfigurationResponse
Retrieves the instance ARN and application ARN for the connection.
337 |
# File 'sig/client.rbs', line 337 def describe_lake_formation_identity_center_configuration: ( |
#describe_resource(params = {}) ⇒ Types::DescribeResourceResponse
Retrieves the current data access role for the given resource registered in Lake Formation.
347 |
# File 'sig/client.rbs', line 347 def describe_resource: ( |
#describe_transaction(params = {}) ⇒ Types::DescribeTransactionResponse
Returns the details of a single transaction.
357 |
# File 'sig/client.rbs', line 357 def describe_transaction: ( |
#extend_transaction(params = {}) ⇒ Struct
Indicates to the service that the specified transaction is still active and should not be treated as idle and aborted.
Write transactions that remain idle for a long period are automatically aborted unless explicitly extended.
366 |
# File 'sig/client.rbs', line 366 def extend_transaction: ( |
#get_data_cells_filter(params = {}) ⇒ Types::GetDataCellsFilterResponse
Returns a data cells filter.
376 |
# File 'sig/client.rbs', line 376 def get_data_cells_filter: ( |
#get_data_lake_principal(params = {}) ⇒ Types::GetDataLakePrincipalResponse
Returns the identity of the invoking principal.
389 |
# File 'sig/client.rbs', line 389 def get_data_lake_principal: ( |
#get_data_lake_settings(params = {}) ⇒ Types::GetDataLakeSettingsResponse
Retrieves the list of the data lake administrators of a Lake Formation-managed data lake.
398 |
# File 'sig/client.rbs', line 398 def get_data_lake_settings: ( |
#get_effective_permissions_for_path(params = {}) ⇒ Types::GetEffectivePermissionsForPathResponse
Returns the Lake Formation permissions for a specified table or
database resource located at a path in Amazon S3.
GetEffectivePermissionsForPath will not return databases and tables
if the catalog is encrypted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
409 |
# File 'sig/client.rbs', line 409 def get_effective_permissions_for_path: ( |
#get_lf_tag(params = {}) ⇒ Types::GetLFTagResponse
Returns an LF-tag definition.
424 |
# File 'sig/client.rbs', line 424 def get_lf_tag: ( |
#get_lf_tag_expression(params = {}) ⇒ Types::GetLFTagExpressionResponse
Returns the details about the LF-Tag expression. The caller must be a
data lake admin or must have DESCRIBE permission on the LF-Tag
expression resource.
438 |
# File 'sig/client.rbs', line 438 def get_lf_tag_expression: ( |
#get_query_state(params = {}) ⇒ Types::GetQueryStateResponse
Returns the state of a query previously submitted. Clients are
expected to poll GetQueryState to monitor the current state of the
planning before retrieving the work units. A query state is only
visible to the principal that made the initial call to
StartQueryPlanning.
449 |
# File 'sig/client.rbs', line 449 def get_query_state: ( |
#get_query_statistics(params = {}) ⇒ Types::GetQueryStatisticsResponse
Retrieves statistics on the planning and execution of a query.
461 |
# File 'sig/client.rbs', line 461 def get_query_statistics: ( |
#get_resource_lf_tags(params = {}) ⇒ Types::GetResourceLFTagsResponse
Returns the LF-tags applied to a resource.
473 |
# File 'sig/client.rbs', line 473 def get_resource_lf_tags: ( |
#get_table_objects(params = {}) ⇒ Types::GetTableObjectsResponse
Returns the set of Amazon S3 objects that make up the specified governed table. A transaction ID or timestamp can be specified for time-travel queries.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
486 |
# File 'sig/client.rbs', line 486 def get_table_objects: ( |
#get_temporary_data_location_credentials(params = {}) ⇒ Types::GetTemporaryDataLocationCredentialsResponse
Allows a user or application in a secure environment to access data in a specific Amazon S3 location registered with Lake Formation by providing temporary scoped credentials that are limited to the requested data location and the caller's authorized access level.
GetDataAccess is logged in CloudTrail whenever a principal requests
temporary data location credentials to access data in a data lake
location that is registered with Lake Formation.
The API operation returns an error in the following scenarios:
-
The data location is not registered with Lake Formation.
-
No Glue table is associated with the data location.
-
The caller doesn't have required permissions on the associated table. The caller must have
SELECTorSUPERpermissions on the associated table, and credential vending for full table access must be enabled in the data lake settings.For more information, see Application integration for full table access.
-
The data location is in a different Amazon Web Services Region. Lake Formation doesn't support cross-Region access when vending credentials for a data location. Lake Formation only supports Amazon S3 paths registered within the same Region as the API call.
505 |
# File 'sig/client.rbs', line 505 def get_temporary_data_location_credentials: ( |
#get_temporary_glue_partition_credentials(params = {}) ⇒ Types::GetTemporaryGluePartitionCredentialsResponse
This API is identical to GetTemporaryTableCredentials except that
this is used when the target Data Catalog resource is of type
Partition. Lake Formation restricts the permission of the vended
credentials with the same scope down policy which restricts access to
a single Amazon S3 prefix.
523 |
# File 'sig/client.rbs', line 523 def get_temporary_glue_partition_credentials: ( |
#get_temporary_glue_table_credentials(params = {}) ⇒ Types::GetTemporaryGlueTableCredentialsResponse
Allows a caller in a secure environment to assume a role with permission to access Amazon S3. In order to vend such credentials, Lake Formation assumes the role associated with a registered location, for example an Amazon S3 bucket, with a scope down policy which restricts the access to a single prefix.
To call this API, the role that the service assumes must have
lakeformation:GetDataAccess permission on the resource.
546 |
# File 'sig/client.rbs', line 546 def get_temporary_glue_table_credentials: ( |
#get_work_unit_results(params = {}) ⇒ Types::GetWorkUnitResultsResponse
Returns the work units resulting from the query. Work units can be executed in any order and in parallel.
570 |
# File 'sig/client.rbs', line 570 def get_work_unit_results: ( |
#get_work_units(params = {}) ⇒ Types::GetWorkUnitsResponse
Retrieves the work units generated by the StartQueryPlanning
operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
584 |
# File 'sig/client.rbs', line 584 def get_work_units: ( |
#grant_permissions(params = {}) ⇒ Struct
Grants permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3.
For information about permissions, see Security and Access Control to Metadata and Data.
595 |
# File 'sig/client.rbs', line 595 def grant_permissions: ( |
#list_data_cells_filter(params = {}) ⇒ Types::ListDataCellsFilterResponse
Lists all the data cell filters on a table.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
615 |
# File 'sig/client.rbs', line 615 def list_data_cells_filter: ( |
#list_lake_formation_opt_ins(params = {}) ⇒ Types::ListLakeFormationOptInsResponse
Retrieve the current list of resources and principals that are opt in to enforce Lake Formation permissions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
661 |
# File 'sig/client.rbs', line 661 def list_lake_formation_opt_ins: ( |
#list_lf_tag_expressions(params = {}) ⇒ Types::ListLFTagExpressionsResponse
Returns the LF-Tag expressions in caller’s account filtered based on caller's permissions. Data Lake and read only admins implicitly can see all tag expressions in their account, else caller needs DESCRIBE permissions on tag expression.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
634 |
# File 'sig/client.rbs', line 634 def list_lf_tag_expressions: ( |
#list_lf_tags(params = {}) ⇒ Types::ListLFTagsResponse
Lists LF-tags that the requester has permission to view.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
647 |
# File 'sig/client.rbs', line 647 def list_lf_tags: ( |
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Returns a list of the principal permissions on the resource, filtered by the permissions of the caller. For example, if you are granted an ALTER permission, you are able to see only the principal permissions for ALTER.
This operation returns only those permissions that have been
explicitly granted. If both Principal and Resource parameters are
provided, the response returns effective permissions rather than the
explicitly granted permissions.
For information about permissions, see Security and Access Control to Metadata and Data.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
677 |
# File 'sig/client.rbs', line 677 def list_permissions: ( |
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Lists the resources registered to be managed by the Data Catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
696 |
# File 'sig/client.rbs', line 696 def list_resources: ( |
#list_table_storage_optimizers(params = {}) ⇒ Types::ListTableStorageOptimizersResponse
Returns the configuration of all storage optimizers associated with a specified table.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
715 |
# File 'sig/client.rbs', line 715 def list_table_storage_optimizers: ( |
#list_transactions(params = {}) ⇒ Types::ListTransactionsResponse
Returns metadata about transactions and their status. To prevent the response from growing indefinitely, only uncommitted transactions and those available for time-travel queries are returned.
This operation can help you identify uncommitted transactions or to get information about transactions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
731 |
# File 'sig/client.rbs', line 731 def list_transactions: ( |
#put_data_lake_settings(params = {}) ⇒ Struct
Sets the list of data lake administrators who have admin privileges on all resources managed by Lake Formation. For more information on admin privileges, see Granting Lake Formation Permissions.
This API replaces the current list of data lake admins with the new list being passed. To add an admin, fetch the current list and add the new admin to that list and pass that list in this API.
743 |
# File 'sig/client.rbs', line 743 def put_data_lake_settings: ( |
#register_resource(params = {}) ⇒ Struct
Registers the resource as managed by the Data Catalog.
To add or update data, Lake Formation needs read/write access to the chosen data location. Choose a role that you know has permission to do this, or choose the AWSServiceRoleForLakeFormationDataAccess service-linked role. When you register the first Amazon S3 path, the service-linked role and a new inline policy are created on your behalf. Lake Formation adds the first path to the inline policy and attaches it to the service-linked role. When you register subsequent paths, Lake Formation adds the path to the existing policy.
The following request registers a new location and gives Lake Formation permission to use the service-linked role to access that location.
ResourceArn = arn:aws:s3:::my-bucket/ UseServiceLinkedRole = true
If UseServiceLinkedRole is not set to true, you must provide or set
the RoleArn:
arn:aws:iam::12345:role/my-data-access-role
790 |
# File 'sig/client.rbs', line 790 def register_resource: ( |
#remove_lf_tags_from_resource(params = {}) ⇒ Types::RemoveLFTagsFromResourceResponse
Removes an LF-tag from the resource. Only database, table, or
tableWithColumns resource are allowed. To tag columns, use the column
inclusion list in tableWithColumns to specify column input.
806 |
# File 'sig/client.rbs', line 806 def remove_lf_tags_from_resource: ( |
#revoke_permissions(params = {}) ⇒ Struct
Revokes permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3.
823 |
# File 'sig/client.rbs', line 823 def revoke_permissions: ( |
#search_databases_by_lf_tags(params = {}) ⇒ Types::SearchDatabasesByLFTagsResponse
This operation allows a search on DATABASE resources by
TagCondition. This operation is used by admins who want to grant
user permissions on certain TagConditions. Before making a grant,
the admin can use SearchDatabasesByTags to find all resources where
the given TagConditions are valid to verify whether the returned
resources can be shared.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
843 |
# File 'sig/client.rbs', line 843 def search_databases_by_lf_tags: ( |
#search_tables_by_lf_tags(params = {}) ⇒ Types::SearchTablesByLFTagsResponse
This operation allows a search on TABLE resources by LFTags. This
will be used by admins who want to grant user permissions on certain
LF-tags. Before making a grant, the admin can use
SearchTablesByLFTags to find all resources where the given LFTags
are valid to verify whether the returned resources can be shared.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
862 |
# File 'sig/client.rbs', line 862 def search_tables_by_lf_tags: ( |
#start_query_planning(params = {}) ⇒ Types::StartQueryPlanningResponse
Submits a request to process a query statement.
This operation generates work units that can be retrieved with the
GetWorkUnits operation as soon as the query state is
WORKUNITS_AVAILABLE or FINISHED.
880 |
# File 'sig/client.rbs', line 880 def start_query_planning: ( |
#start_transaction(params = {}) ⇒ Types::StartTransactionResponse
Starts a new transaction and returns its transaction ID. Transaction IDs are opaque objects that you can use to identify a transaction.
897 |
# File 'sig/client.rbs', line 897 def start_transaction: ( |
#update_data_cells_filter(params = {}) ⇒ Struct
Updates a data cell filter.
906 |
# File 'sig/client.rbs', line 906 def update_data_cells_filter: ( |
#update_lake_formation_identity_center_configuration(params = {}) ⇒ Struct
Updates the IAM Identity Center connection parameters.
944 |
# File 'sig/client.rbs', line 944 def update_lake_formation_identity_center_configuration: ( |
#update_lf_tag(params = {}) ⇒ Struct
Updates the list of possible values for the specified LF-tag key. If the LF-tag does not exist, the operation throws an EntityNotFoundException. The values in the delete key values will be deleted from list of possible values. If any value in the delete key values is attached to a resource, then API errors out with a 400 Exception - "Update not allowed". Untag the attribute before deleting the LF-tag key's value.
915 |
# File 'sig/client.rbs', line 915 def update_lf_tag: ( |
#update_lf_tag_expression(params = {}) ⇒ Struct
Updates the name of the LF-Tag expression to the new description and
expression body provided. Updating a LF-Tag expression immediately
changes the permission boundaries of all existing LFTagPolicy
permission grants that reference the given LF-Tag expression.
927 |
# File 'sig/client.rbs', line 927 def update_lf_tag_expression: ( |
#update_resource(params = {}) ⇒ Struct
Updates the data access role used for vending access to the given (registered) resource in Lake Formation.
974 |
# File 'sig/client.rbs', line 974 def update_resource: ( |
#update_table_objects(params = {}) ⇒ Struct
Updates the manifest of Amazon S3 objects that make up the specified governed table.
987 |
# File 'sig/client.rbs', line 987 def update_table_objects: ( |
#update_table_storage_optimizer(params = {}) ⇒ Types::UpdateTableStorageOptimizerResponse
Updates the configuration of the storage optimizers for a table.
1015 |
# File 'sig/client.rbs', line 1015 def update_table_storage_optimizer: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4377 4378 4379 |
# File 'lib/aws-sdk-lakeformation/client.rb', line 4377 def waiter_names [] end |