Class: Aws::LakeFormation::Types::CreateLakeFormationIdentityCenterConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, view definitions, and other control information to manage your Lake Formation environment.

Returns:

  • (String)


582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-lakeformation/types.rb', line 582

class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new(
  :catalog_id,
  :instance_arn,
  :external_filtering,
  :share_recipients,
  :service_integrations)
  SENSITIVE = []
  include Aws::Structure
end

#external_filteringTypes::ExternalFilteringConfiguration

A list of the account IDs of Amazon Web Services accounts of third-party applications that are allowed to access data managed by Lake Formation.



582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-lakeformation/types.rb', line 582

class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new(
  :catalog_id,
  :instance_arn,
  :external_filtering,
  :share_recipients,
  :service_integrations)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the IAM Identity Center instance for which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-lakeformation/types.rb', line 582

class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new(
  :catalog_id,
  :instance_arn,
  :external_filtering,
  :share_recipients,
  :service_integrations)
  SENSITIVE = []
  include Aws::Structure
end

#service_integrationsArray<Types::ServiceIntegrationUnion>

A list of service integrations for enabling trusted identity propagation with external services such as Redshift.

Returns:



582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-lakeformation/types.rb', line 582

class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new(
  :catalog_id,
  :instance_arn,
  :external_filtering,
  :share_recipients,
  :service_integrations)
  SENSITIVE = []
  include Aws::Structure
end

#share_recipientsArray<Types::DataLakePrincipal>

A list of Amazon Web Services account IDs and/or Amazon Web Services organization/organizational unit ARNs that are allowed to access data managed by Lake Formation.

If the ShareRecipients list includes valid values, a resource share is created with the principals you want to have access to the resources.

If the ShareRecipients value is null or the list is empty, no resource share is created.

Returns:



582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-lakeformation/types.rb', line 582

class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new(
  :catalog_id,
  :instance_arn,
  :external_filtering,
  :share_recipients,
  :service_integrations)
  SENSITIVE = []
  include Aws::Structure
end