Class: Aws::LakeFormation::Types::DataCellsFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

A structure that describes certain columns on certain rows.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_namesArray<String>

A list of column names and/or nested column attributes. When specifying nested attributes, use a qualified dot (.) delimited format such as “address”.“zip”. Nested attributes within this list may not exceed a depth of 5.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#column_wildcardTypes::ColumnWildcard

A wildcard with exclusions.

You must specify either a ColumnNames list or the ColumnWildCard.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

A database in the Glue Data Catalog.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name given by the user to the data filter cell.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#row_filterTypes::RowFilter

A PartiQL predicate.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#table_catalog_idString

The ID of the catalog to which the table belongs.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

A table in the database.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The ID of the data cells filter version.



675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-lakeformation/types.rb', line 675

class DataCellsFilter < Struct.new(
  :table_catalog_id,
  :database_name,
  :table_name,
  :name,
  :row_filter,
  :column_names,
  :column_wildcard,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end