Class: Aws::LakeFormation::Types::DataLocationResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::DataLocationResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
A structure for a data location object where permissions are granted or revoked.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog where the location is registered with Lake Formation.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the data location resource.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog where the location is registered with Lake Formation. By default, it is the account ID of the caller.
892 893 894 895 896 897 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 892 class DataLocationResource < Struct.new( :catalog_id, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the data location resource.
892 893 894 895 896 897 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 892 class DataLocationResource < Struct.new( :catalog_id, :resource_arn) SENSITIVE = [] include Aws::Structure end |