Class: Aws::LakeFormation::Types::GetResourceLFTagsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

Returns:

  • (String)


1708
1709
1710
1711
1712
1713
1714
# File 'lib/aws-sdk-lakeformation/types.rb', line 1708

class GetResourceLFTagsRequest < Struct.new(
  :catalog_id,
  :resource,
  :show_assigned_lf_tags)
  SENSITIVE = []
  include Aws::Structure
end

#resourceTypes::Resource

The database, table, or column resource for which you want to return LF-tags.

Returns:



1708
1709
1710
1711
1712
1713
1714
# File 'lib/aws-sdk-lakeformation/types.rb', line 1708

class GetResourceLFTagsRequest < Struct.new(
  :catalog_id,
  :resource,
  :show_assigned_lf_tags)
  SENSITIVE = []
  include Aws::Structure
end

#show_assigned_lf_tagsBoolean

Indicates whether to show the assigned LF-tags.

Returns:

  • (Boolean)


1708
1709
1710
1711
1712
1713
1714
# File 'lib/aws-sdk-lakeformation/types.rb', line 1708

class GetResourceLFTagsRequest < Struct.new(
  :catalog_id,
  :resource,
  :show_assigned_lf_tags)
  SENSITIVE = []
  include Aws::Structure
end