Class: Aws::LakeFormation::Types::LFTagPair

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

A structure containing an LF-tag key-value pair.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
# File 'lib/aws-sdk-lakeformation/types.rb', line 2375

class LFTagPair < Struct.new(
  :catalog_id,
  :tag_key,
  :tag_values)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keyString

The key-name for the LF-tag.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
# File 'lib/aws-sdk-lakeformation/types.rb', line 2375

class LFTagPair < Struct.new(
  :catalog_id,
  :tag_key,
  :tag_values)
  SENSITIVE = []
  include Aws::Structure
end

#tag_valuesArray<String>

A list of possible values an attribute can take.

Returns:

  • (Array<String>)


2375
2376
2377
2378
2379
2380
2381
# File 'lib/aws-sdk-lakeformation/types.rb', line 2375

class LFTagPair < Struct.new(
  :catalog_id,
  :tag_key,
  :tag_values)
  SENSITIVE = []
  include Aws::Structure
end