Class: Aws::LakeFormation::Types::ListTransactionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::ListTransactionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The catalog for which to list transactions.
-
#max_results ⇒ Integer
The maximum number of transactions to return in a single call.
-
#next_token ⇒ String
A continuation token if this is not the first call to retrieve transactions.
-
#status_filter ⇒ String
A filter indicating the status of transactions to return.
Instance Attribute Details
#catalog_id ⇒ String
The catalog for which to list transactions. Defaults to the account ID of the caller.
2833 2834 2835 2836 2837 2838 2839 2840 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2833 class ListTransactionsRequest < Struct.new( :catalog_id, :status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of transactions to return in a single call.
2833 2834 2835 2836 2837 2838 2839 2840 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2833 class ListTransactionsRequest < Struct.new( :catalog_id, :status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token if this is not the first call to retrieve transactions.
2833 2834 2835 2836 2837 2838 2839 2840 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2833 class ListTransactionsRequest < Struct.new( :catalog_id, :status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status_filter ⇒ String
A filter indicating the status of transactions to return. Options are ALL | COMPLETED | COMMITTED | ABORTED | ACTIVE. The default is ALL.
2833 2834 2835 2836 2837 2838 2839 2840 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2833 class ListTransactionsRequest < Struct.new( :catalog_id, :status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |