Class: Aws::LakeFormation::Types::ListTransactionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::ListTransactionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A continuation token indicating whether additional data is available.
-
#transactions ⇒ Array<Types::TransactionDescription>
A list of transactions.
Instance Attribute Details
#next_token ⇒ String
A continuation token indicating whether additional data is available.
2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2854 class ListTransactionsResponse < Struct.new( :transactions, :next_token) SENSITIVE = [] include Aws::Structure end |
#transactions ⇒ Array<Types::TransactionDescription>
A list of transactions. The record for each transaction is a TransactionDescription object.
2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2854 class ListTransactionsResponse < Struct.new( :transactions, :next_token) SENSITIVE = [] include Aws::Structure end |