Class: Aws::LakeFormation::Types::PermissionTypeMismatchException
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::PermissionTypeMismatchException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
The engine does not support filtering data based on the enforced permissions. For example, if you call the GetTemporaryGlueTableCredentials operation with SupportedPermissionType equal to ColumnPermission, but cell-level permissions exist on the table, this exception is thrown.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message describing the problem.
Instance Attribute Details
#message ⇒ String
A message describing the problem.
2920 2921 2922 2923 2924 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2920 class PermissionTypeMismatchException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |