Class: Aws::LakeFormation::Types::QuerySessionContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.

For more information about how to utilize QuerySessionContext, see Lake Formation workflow for application integration API operations in the developer guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_contextHash<String,String>

An opaque string-string map passed by the query engine.

Returns:

  • (Hash<String,String>)


3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141

class QuerySessionContext < Struct.new(
  :query_id,
  :query_start_time,
  :cluster_id,
  :query_authorization_id,
  :additional_context)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_idString

An identifier string for the consumer cluster.

Returns:

  • (String)


3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141

class QuerySessionContext < Struct.new(
  :query_id,
  :query_start_time,
  :cluster_id,
  :query_authorization_id,
  :additional_context)
  SENSITIVE = []
  include Aws::Structure
end

#query_authorization_idString

A cryptographically generated query identifier generated by Glue or Lake Formation.

Returns:

  • (String)


3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141

class QuerySessionContext < Struct.new(
  :query_id,
  :query_start_time,
  :cluster_id,
  :query_authorization_id,
  :additional_context)
  SENSITIVE = []
  include Aws::Structure
end

#query_idString

A unique identifier generated by the query engine for the query.

Returns:

  • (String)


3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141

class QuerySessionContext < Struct.new(
  :query_id,
  :query_start_time,
  :cluster_id,
  :query_authorization_id,
  :additional_context)
  SENSITIVE = []
  include Aws::Structure
end

#query_start_timeTime

A timestamp provided by the query engine for when the query started.

Returns:

  • (Time)


3141
3142
3143
3144
3145
3146
3147
3148
3149
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141

class QuerySessionContext < Struct.new(
  :query_id,
  :query_start_time,
  :cluster_id,
  :query_authorization_id,
  :additional_context)
  SENSITIVE = []
  include Aws::Structure
end