Class: Aws::LakeFormation::Types::RegisterResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::RegisterResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_resource_owner_account ⇒ String
The Amazon Web Services account that owns the Glue tables associated with specific Amazon S3 locations.
-
#hybrid_access_enabled ⇒ Boolean
Specifies whether the data access of tables pointing to the location can be managed by both Lake Formation permissions as well as Amazon S3 bucket policies.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that you want to register.
-
#role_arn ⇒ String
The identifier for the role that registers the resource.
-
#use_service_linked_role ⇒ Boolean
Designates an Identity and Access Management (IAM) service-linked role by registering this role with the Data Catalog.
-
#with_federation ⇒ Boolean
Whether or not the resource is a federated resource.
-
#with_privileged_access ⇒ Boolean
Grants the calling principal the permissions to perform all supported Lake Formation operations on the registered data location.
Instance Attribute Details
#expected_resource_owner_account ⇒ String
The Amazon Web Services account that owns the Glue tables associated with specific Amazon S3 locations.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#hybrid_access_enabled ⇒ Boolean
Specifies whether the data access of tables pointing to the location can be managed by both Lake Formation permissions as well as Amazon S3 bucket policies.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that you want to register.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The identifier for the role that registers the resource.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#use_service_linked_role ⇒ Boolean
Designates an Identity and Access Management (IAM) service-linked role by registering this role with the Data Catalog. A service-linked role is a unique type of IAM role that is linked directly to Lake Formation.
For more information, see [Using Service-Linked Roles for Lake Formation].
[1]: docs.aws.amazon.com/lake-formation/latest/dg/service-linked-roles.html
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#with_federation ⇒ Boolean
Whether or not the resource is a federated resource.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |
#with_privileged_access ⇒ Boolean
Grants the calling principal the permissions to perform all supported Lake Formation operations on the registered data location.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3217 class RegisterResourceRequest < Struct.new( :resource_arn, :use_service_linked_role, :role_arn, :with_federation, :hybrid_access_enabled, :with_privileged_access, :expected_resource_owner_account) SENSITIVE = [] include Aws::Structure end |