Class: Aws::LakeFormation::Types::RemoveLFTagsFromResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

Returns:

  • (String)


3259
3260
3261
3262
3263
3264
3265
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259

class RemoveLFTagsFromResourceRequest < Struct.new(
  :catalog_id,
  :resource,
  :lf_tags)
  SENSITIVE = []
  include Aws::Structure
end

#lf_tagsArray<Types::LFTagPair>

The LF-tags to be removed from the resource.

Returns:



3259
3260
3261
3262
3263
3264
3265
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259

class RemoveLFTagsFromResourceRequest < Struct.new(
  :catalog_id,
  :resource,
  :lf_tags)
  SENSITIVE = []
  include Aws::Structure
end

#resourceTypes::Resource

The database, table, or column resource where you want to remove an LF-tag.

Returns:



3259
3260
3261
3262
3263
3264
3265
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259

class RemoveLFTagsFromResourceRequest < Struct.new(
  :catalog_id,
  :resource,
  :lf_tags)
  SENSITIVE = []
  include Aws::Structure
end