Class: Aws::LakeFormation::Types::SearchDatabasesByLFTagsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::SearchDatabasesByLFTagsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog.
-
#expression ⇒ Array<Types::LFTag>
A list of conditions (
LFTagstructures) to search for in database resources. -
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
A continuation token, if this is not the first call to retrieve this list.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
3533 3534 3535 3536 3537 3538 3539 3540 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3533 class SearchDatabasesByLFTagsRequest < Struct.new( :next_token, :max_results, :catalog_id, :expression) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ Array<Types::LFTag>
A list of conditions (LFTag structures) to search for in database resources.
3533 3534 3535 3536 3537 3538 3539 3540 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3533 class SearchDatabasesByLFTagsRequest < Struct.new( :next_token, :max_results, :catalog_id, :expression) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
3533 3534 3535 3536 3537 3538 3539 3540 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3533 class SearchDatabasesByLFTagsRequest < Struct.new( :next_token, :max_results, :catalog_id, :expression) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is not the first call to retrieve this list.
3533 3534 3535 3536 3537 3538 3539 3540 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3533 class SearchDatabasesByLFTagsRequest < Struct.new( :next_token, :max_results, :catalog_id, :expression) SENSITIVE = [] include Aws::Structure end |