Class: Aws::LakeFormation::Types::ServiceIntegrationUnion

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

Note:

ServiceIntegrationUnion is a union - when making an API calls you must set exactly one of the members.

Note:

ServiceIntegrationUnion is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ServiceIntegrationUnion corresponding to the set member.

A union structure representing different service integration types.

Direct Known Subclasses

Redshift, Unknown

Defined Under Namespace

Classes: Redshift, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#redshiftArray<Types::RedshiftScopeUnion>

Redshift service integration configuration.

Returns:



3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
# File 'lib/aws-sdk-lakeformation/types.rb', line 3623

class ServiceIntegrationUnion < Struct.new(
  :redshift,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Redshift < ServiceIntegrationUnion; end
  class Unknown < ServiceIntegrationUnion; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3623
3624
3625
# File 'lib/aws-sdk-lakeformation/types.rb', line 3623

def unknown
  @unknown
end