Class: Aws::LakeFormation::Types::TemporaryCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

A temporary set of credentials for an Lake Formation user. These credentials are scoped down to only access the raw data sources that the user has access to.

The temporary security credentials consist of an access key and a session token. The access key consists of an access key ID and a secret key. When the credentials are created, they are associated with an IAM access control policy that limits what the user can do when using the credentials.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_key_idString

The access key ID for the temporary credentials.

Returns:

  • (String)


3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/aws-sdk-lakeformation/types.rb', line 3946

class TemporaryCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = []
  include Aws::Structure
end

#expirationTime

The date and time when the temporary credentials expire.

Returns:

  • (Time)


3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/aws-sdk-lakeformation/types.rb', line 3946

class TemporaryCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = []
  include Aws::Structure
end

#secret_access_keyString

The secret key for the temporary credentials.

Returns:

  • (String)


3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/aws-sdk-lakeformation/types.rb', line 3946

class TemporaryCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = []
  include Aws::Structure
end

#session_tokenString

The session token for the temporary credentials.

Returns:

  • (String)


3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/aws-sdk-lakeformation/types.rb', line 3946

class TemporaryCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = []
  include Aws::Structure
end