Class: Aws::LakeFormation::Types::UpdateTableStorageOptimizerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::UpdateTableStorageOptimizerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#result ⇒ String
A response indicating the success of failure of the operation.
Instance Attribute Details
#result ⇒ String
A response indicating the success of failure of the operation.
4303 4304 4305 4306 4307 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 4303 class UpdateTableStorageOptimizerResponse < Struct.new( :result) SENSITIVE = [] include Aws::Structure end |