Class: Aws::LakeFormation::Types::CreateLakeFormationIdentityCenterConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::CreateLakeFormationIdentityCenterConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog.
-
#external_filtering ⇒ Types::ExternalFilteringConfiguration
A list of the account IDs of Amazon Web Services accounts of third-party applications that are allowed to access data managed by Lake Formation.
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance for which the operation will be executed.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, view definitions, and other control information to manage your Lake Formation environment.
488 489 490 491 492 493 494 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 488 class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new( :catalog_id, :instance_arn, :external_filtering) SENSITIVE = [] include Aws::Structure end |
#external_filtering ⇒ Types::ExternalFilteringConfiguration
A list of the account IDs of Amazon Web Services accounts of third-party applications that are allowed to access data managed by Lake Formation.
488 489 490 491 492 493 494 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 488 class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new( :catalog_id, :instance_arn, :external_filtering) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance for which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
488 489 490 491 492 493 494 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 488 class CreateLakeFormationIdentityCenterConfigurationRequest < Struct.new( :catalog_id, :instance_arn, :external_filtering) SENSITIVE = [] include Aws::Structure end |