Class: Aws::LakeFormation::Types::GetTemporaryDataLocationCredentialsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::GetTemporaryDataLocationCredentialsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure used to include auditing information on the privileged API.
-
#credentials_scope ⇒ String
The credential scope is determined by the caller’s Lake Formation permission on the associated table.
-
#data_locations ⇒ Array<String>
The Amazon S3 data location that you want to access.
-
#duration_seconds ⇒ Integer
The time period, between 900 and 43,200 seconds, for the timeout of the temporary credentials.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure used to include auditing information on the privileged API.
1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 1846 class GetTemporaryDataLocationCredentialsRequest < Struct.new( :duration_seconds, :audit_context, :data_locations, :credentials_scope) SENSITIVE = [] include Aws::Structure end |
#credentials_scope ⇒ String
The credential scope is determined by the caller’s Lake Formation permission on the associated table. Credential scope can be either:
-
READ - Provides read-only access to the data location.
-
READ_WRITE - Provides both read and write access to the data location.
1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 1846 class GetTemporaryDataLocationCredentialsRequest < Struct.new( :duration_seconds, :audit_context, :data_locations, :credentials_scope) SENSITIVE = [] include Aws::Structure end |
#data_locations ⇒ Array<String>
The Amazon S3 data location that you want to access.
1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 1846 class GetTemporaryDataLocationCredentialsRequest < Struct.new( :duration_seconds, :audit_context, :data_locations, :credentials_scope) SENSITIVE = [] include Aws::Structure end |
#duration_seconds ⇒ Integer
The time period, between 900 and 43,200 seconds, for the timeout of the temporary credentials.
1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 1846 class GetTemporaryDataLocationCredentialsRequest < Struct.new( :duration_seconds, :audit_context, :data_locations, :credentials_scope) SENSITIVE = [] include Aws::Structure end |