Class: Aws::LakeFormation::Types::LFTagPair
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::LFTagPair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
A structure containing an LF-tag key-value pair.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog.
-
#tag_key ⇒ String
The key-name for the LF-tag.
-
#tag_values ⇒ Array<String>
A list of possible values an attribute can take.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
2375 2376 2377 2378 2379 2380 2381 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 2375 class LFTagPair < Struct.new( :catalog_id, :tag_key, :tag_values) SENSITIVE = [] include Aws::Structure end |