Class: Aws::LakeFormation::Types::PutDataLakeSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lakeformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
# File 'lib/aws-sdk-lakeformation/types.rb', line 3041

class PutDataLakeSettingsRequest < Struct.new(
  :catalog_id,
  :data_lake_settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_lake_settingsTypes::DataLakeSettings

A structure representing a list of Lake Formation principals designated as data lake administrators.



3041
3042
3043
3044
3045
3046
# File 'lib/aws-sdk-lakeformation/types.rb', line 3041

class PutDataLakeSettingsRequest < Struct.new(
  :catalog_id,
  :data_lake_settings)
  SENSITIVE = []
  include Aws::Structure
end