Class: Aws::LakeFormation::Types::QuerySessionContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::QuerySessionContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.
For more information about how to utilize QuerySessionContext, see Lake Formation workflow for application integration API operations in the developer guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_context ⇒ Hash<String,String>
An opaque string-string map passed by the query engine.
-
#cluster_id ⇒ String
An identifier string for the consumer cluster.
-
#query_authorization_id ⇒ String
A cryptographically generated query identifier generated by Glue or Lake Formation.
-
#query_id ⇒ String
A unique identifier generated by the query engine for the query.
-
#query_start_time ⇒ Time
A timestamp provided by the query engine for when the query started.
Instance Attribute Details
#additional_context ⇒ Hash<String,String>
An opaque string-string map passed by the query engine.
3141 3142 3143 3144 3145 3146 3147 3148 3149 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141 class QuerySessionContext < Struct.new( :query_id, :query_start_time, :cluster_id, :query_authorization_id, :additional_context) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
An identifier string for the consumer cluster.
3141 3142 3143 3144 3145 3146 3147 3148 3149 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141 class QuerySessionContext < Struct.new( :query_id, :query_start_time, :cluster_id, :query_authorization_id, :additional_context) SENSITIVE = [] include Aws::Structure end |
#query_authorization_id ⇒ String
A cryptographically generated query identifier generated by Glue or Lake Formation.
3141 3142 3143 3144 3145 3146 3147 3148 3149 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141 class QuerySessionContext < Struct.new( :query_id, :query_start_time, :cluster_id, :query_authorization_id, :additional_context) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
A unique identifier generated by the query engine for the query.
3141 3142 3143 3144 3145 3146 3147 3148 3149 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141 class QuerySessionContext < Struct.new( :query_id, :query_start_time, :cluster_id, :query_authorization_id, :additional_context) SENSITIVE = [] include Aws::Structure end |
#query_start_time ⇒ Time
A timestamp provided by the query engine for when the query started.
3141 3142 3143 3144 3145 3146 3147 3148 3149 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3141 class QuerySessionContext < Struct.new( :query_id, :query_start_time, :cluster_id, :query_authorization_id, :additional_context) SENSITIVE = [] include Aws::Structure end |