Class: Aws::LakeFormation::Types::RemoveLFTagsFromResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::RemoveLFTagsFromResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog.
-
#lf_tags ⇒ Array<Types::LFTagPair>
The LF-tags to be removed from the resource.
-
#resource ⇒ Types::Resource
The database, table, or column resource where you want to remove an LF-tag.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
3259 3260 3261 3262 3263 3264 3265 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259 class RemoveLFTagsFromResourceRequest < Struct.new( :catalog_id, :resource, :lf_tags) SENSITIVE = [] include Aws::Structure end |
#lf_tags ⇒ Array<Types::LFTagPair>
The LF-tags to be removed from the resource.
3259 3260 3261 3262 3263 3264 3265 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259 class RemoveLFTagsFromResourceRequest < Struct.new( :catalog_id, :resource, :lf_tags) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::Resource
The database, table, or column resource where you want to remove an LF-tag.
3259 3260 3261 3262 3263 3264 3265 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3259 class RemoveLFTagsFromResourceRequest < Struct.new( :catalog_id, :resource, :lf_tags) SENSITIVE = [] include Aws::Structure end |