Class: Aws::LakeFormation::Types::RevokePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LakeFormation::Types::RevokePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lakeformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The identifier for the Data Catalog.
-
#condition ⇒ Types::Condition
A Lake Formation condition, which applies to permissions and opt-ins that contain an expression.
-
#permissions ⇒ Array<String>
The permissions revoked to the principal on the resource.
-
#permissions_with_grant_option ⇒ Array<String>
Indicates a list of permissions for which to revoke the grant option allowing the principal to pass permissions to other principals.
-
#principal ⇒ Types::DataLakePrincipal
The principal to be revoked permissions on the resource.
-
#resource ⇒ Types::Resource
The resource to which permissions are to be revoked.
Instance Attribute Details
#catalog_id ⇒ String
The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |
#condition ⇒ Types::Condition
A Lake Formation condition, which applies to permissions and opt-ins that contain an expression.
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The permissions revoked to the principal on the resource. For information about permissions, see [Security and Access Control to Metadata and Data].
[1]: docs.aws.amazon.com/lake-formation/latest/dg/security-data-access.html
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |
#permissions_with_grant_option ⇒ Array<String>
Indicates a list of permissions for which to revoke the grant option allowing the principal to pass permissions to other principals.
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ Types::DataLakePrincipal
The principal to be revoked permissions on the resource.
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::Resource
The resource to which permissions are to be revoked.
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-lakeformation/types.rb', line 3476 class RevokePermissionsRequest < Struct.new( :catalog_id, :principal, :resource, :permissions, :condition, :permissions_with_grant_option) SENSITIVE = [] include Aws::Structure end |